package editeur;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Point;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JFrame;

public class Editeur extends JFrame {

	MouseListener mouseListener = null;
	
	public Editeur(int hauteur, int largeur) {
		super("Editeur");
		JFrame.setDefaultLookAndFeelDecorated(true);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		final Planche planche = new Planche();
		add(planche, BorderLayout.CENTER);

		final MouseListener m1 = new MouseAdapter() {
			public void mouseClicked(MouseEvent arg0) {
				try {
					planche.ajouterPoint(arg0.getPoint());
					planche.repaint();
				} catch (PointExistantException e) {
					System.out.println(e.getMessage());
				}
			}
		};
		mouseListener = m1;
		planche.addMouseListener(m1);
		
		FabriqueForme[] fabriques = { new FabriqueEllipse(),
				new FabriqueTriangle() , new FabriqueRectangle() };

		for (final FabriqueForme ff : fabriques) {
			final MouseListener m2 = new MouseAdapter() {
				List<Point> points = new ArrayList<Point>();

				public void mouseClicked(MouseEvent arg0) {
					Point p = planche.point(arg0.getPoint());
					if (p != null) {
						points.add(p);
						if (points.size() == ff.nombrePoints()) {
							planche.ajouterForme(ff.creerForme(points));
							planche.repaint();
							points.clear();
						}
					}
				}
			};

			addKeyListener(new KeyAdapter() {
				public void keyTyped(KeyEvent arg0) {
					if (arg0.getKeyChar() == ff.toucheClavier()) {
						planche.removeMouseListener(mouseListener);
						mouseListener = m2;
						planche.addMouseListener(m2);
					}
				}
			});
		}
		

		setPreferredSize(new Dimension(hauteur, largeur));
		pack();
		setVisible(true);
	}

	public static void main(final String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new Editeur(600, 600);
			}
		});
	}
}
